"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var rxjs_1 = require("rxjs");
var style_1 = require("./style");
var misc_1 = require("../../misc");
var ToastDrag = /** @class */ (function () {
    function ToastDrag(container, remove) {
        var _this = this;
        this.container = container;
        this.remove = remove;
        this.anchor = undefined;
        this.last = undefined;
        this.direction = undefined;
        container.addEventListener('mousedown', function (event) { return _this.start(event); });
        container.addEventListener('touchstart', function (event) { return _this.start(event); });
        document.addEventListener('mousemove', function (event) { return _this.move(event); });
        container.addEventListener('touchmove', function (event) { return _this.move(event); });
        document.addEventListener('mouseup', function (event) { return _this.release(); });
        container.addEventListener('touchend', function (event) { return _this.release(); });
    }
    ToastDrag.prototype.getPos = function (event) {
        if (event instanceof TouchEvent) {
            return { x: event.touches[0].clientX, y: event.touches[0].clientY };
        }
        else {
            return { x: event.clientX, y: event.clientY };
        }
    };
    ToastDrag.prototype.start = function (event) {
        this.anchor = this.getPos(event);
        this.last = this.anchor;
    };
    ToastDrag.prototype.move = function (event) {
        if (this.anchor) {
            event.stopPropagation();
            event.preventDefault();
            var pos = this.getPos(event);
            this.last = pos;
            var dx = pos.x - this.anchor.x;
            var dy = pos.y - this.anchor.y;
            if (!this.direction) {
                if (Math.sqrt(dx * dx + dy * dy) > 16) {
                    if (Math.abs(dx) > Math.abs(dy)) {
                        this.direction = 'horizontal';
                    }
                    else {
                        this.direction = 'vertical';
                    }
                }
            }
            if (this.direction) {
                this.container.classList.add('moving');
                if (this.direction === 'horizontal') {
                    this.container.style.transform = "translateX(" + dx + "px)";
                }
                else {
                    this.container.style.transform = "translateY(" + dy + "px)";
                }
            }
        }
    };
    ToastDrag.prototype.release = function () {
        if (this.anchor && this.last) {
            this.container.classList.remove('moving');
            var dx = this.last.x - this.anchor.x;
            var dy = this.last.y - this.anchor.y;
            if (Math.sqrt(dx * dx + dy * dy) > 128) {
                if (this.direction === 'horizontal') {
                    this.container.style.transform = "translateX(" + 2 * dx + "px)";
                }
                else {
                    this.container.style.transform = "translateY(" + 2 * dy + "px)";
                }
                this.container.style.opacity = '0';
                this.remove();
            }
            else {
                this.container.style.transform = '';
            }
            this.anchor = undefined;
            this.last = undefined;
            this.direction = undefined;
        }
    };
    ToastDrag.prototype.active = function () {
        return this.anchor !== undefined;
    };
    return ToastDrag;
}());
function Toast(options, renderer, content) {
    var classes = this.theme.classes(style_1.ToastStyle);
    var visible = new rxjs_1.BehaviorSubject(false);
    var container$ = renderer.create("div", { class: classes.container, "data-visible": visible },
        renderer.create("div", { class: classes.toast },
            renderer.create("div", { class: classes.content }, content),
            renderer.create("div", { class: classes.actions },
                options.actions || '',
                renderer.create("button", { onclick: function () { return hide(); } },
                    renderer.create(misc_1.Icon, null, "close")))));
    var show = function () { return visible.next(true); };
    var hide = function () {
        visible.next(false);
        remove();
    };
    var remove = function () { return setTimeout(function () { return container$.remove(); }, 150); };
    var drag = new ToastDrag(container$, remove);
    this.track({
        bind: function () {
            setTimeout(show, 10);
            if (!('backdropFilter' in container$.style) && !('-webkit-backdrop-filter' in container$.style)) {
                container$.style.background = 'rgba(64, 64, 64, .95)';
            }
            var timeout = options.timeout || 3000;
            if (timeout !== -1) {
                setTimeout(function () {
                    if (!drag.active())
                        hide();
                }, timeout);
            }
        }
    });
    return container$;
}
exports.Toast = Toast;
//# sourceMappingURL=index.js.map